m_ply(.data, .fun, ..., .expand=TRUE, .progress="none",
.parallel=FALSE).funcreate_progress_barTRUE, apply function in parallel, using parallel
backend provided by foreachm*ply functions are the plyr version of
mapply, specialised according to the type of output they
produce. These functions are just a convenient wrapper around
a*ply with margins = 1 and .fun wrapped in
splat. This function combines the result into a list. If there are no
results, then this function will return a list of length 0
(list()).